%
%   MODELDEMO.M   Sequence of Matlab sample programs that demonstrate  
%              various modeling and simulation techniques (both time and 
%              frequency domain) including a simple Simulink sample 
%
%   Mass-Spring-Dashpot Mechanical System
%     my''(t) + cy'(t) + ky(t)  =  u(t)
%
%   This example has been broken into three parts (3 files), as follows:
%    Demo 1: simple simulation and model conversion techniques    
%    Demo 2: modeling systems in block diagram form (the OLD way) (*** this file ***)
%    Demo 3: modeling with Simulink (the NEW way)
%
%   File prepared by J. R. White, UMass-Lowell (last update: Feb. 2020)
%

      clear all,   close all
      format compact
%
%   open diary file for saving solutions
      delete modeldemo2.out,    diary modeldemo2.out
      disp('  *** MODELDEMO2.OUT  ***   Diary File for MODELDEMO2.M '),   disp(' ')
%
%   Modeling Systems Given in Block Diagram Form (The OLD Way)
%
%   Define the constants for the Under Damping case
      m = 1,   k = 1,   c = 1.2
%
%   Step 1 -- Setup individual transfer functions (see notes for block diagram)
      n1 = 1/m,   d1 = [1 c/m],   sys1 = tf(n1,d1);
      n2 = 1,     d2 = [1 0],     sys2 = tf(n2,d2);
      n3 = k/m,   d3 = [1 c/m],   sys3 = tf(n3,d3);
%
%   Step 2 -- Build a block diagonal (unconnected) system
      sysuct = append(sys1,sys2,sys3);    sysucs = ss(sysuct)
%
%   Step 3 -- Specify interconnections among blocks
      q = [1 0 0;2 1 -3;3 2 0]
%
%   Step 4 -- Specify inputs and outputs
      iu = [1],   iy = [2]
%
%   Step 5 -- Connect system together (this is the desired state-space form)
      syscs = connect(sysucs,q,iu,iy)
%
      syscsm = minreal(syscs)  % find a minimal realization of SS system
      syscz = zpk(syscsm)      % convert to zero, pole, gain form
      sysct = tf(syscz)        % convert to transfer function form
%
      diary off                % turn off diary file
%
%   end of demo