%
%   MODELDEMO.M   Sequence of Matlab sample programs that demonstrate  
%              various modeling and simulation techniques (both time and 
%              frequency domain) including a simple Simulink sample 
%
%   Mass-Spring-Dashpot Mechanical System
%     my''(t) + cy'(t) + ky(t)  =  u(t)
%
%   This example has been broken into three parts (3 files), as follows:
%    Demo 1: simple simulation and model conversion techniques    
%    Demo 2: modeling systems in block diagram form (the OLD way) 
%    Demo 3: modeling with Simulink (the NEW way)  (*** this file ***)
%
%   File prepared by J. R. White, UMass-Lowell (last update: Feb. 2020)
%

      clear all,   close all
      format compact
%
%   open diary file for saving solutions
      delete modeldemo3.out,    diary modeldemo3.out
      disp('  *** MODELDEMO3.OUT  ***   Diary File for MODELDEMO3.M '),   disp(' ')
%
%   Modeling Systems Given in Block Diagram Form with Simulink (The NEW Way)
%
%   Define the constants for the Under Damping case
      m = 1,   k = 1,   c = 1.2
%
%   Display Simulink graphical model on screen
      modeldemo3_sl
%
%   Extract linear model from SIMULINK graphical model (saved in modeldemo3_sl.slx)
      disp('  Data from graphical SIMULINK model')
      [A,B,C,D] = linmod('modeldemo3_sl'),   syss = ss(A,B,C,D);  
      sysz1 = zpk(syss)        % convert to zero, pole, gain form
      syssm = minreal(syss)    % find a minimal realization of SS system
      sysz2 = zpk(syssm)       % convert to ZPK form (after min. realization)
%
      diary off                % turn off diary file
%
%   end of demo
